@@ -34,4 +34,10 @@ class Odoo():
 
   def updateObject(self, object, id, fields):
     res = self.models.execute_kw(self.db, self.uid, self.password, object, 'write', [[id], fields])
-    return res
\ No newline at end of file
+    return res
+  
+  def readModel(self, object, ids):
+    [res] = self.models.execute_kw(self.db, self.uid, self.password, object, 'read', [ids])
+    print(json.dumps(res))
+    return res
+    
\ No newline at end of file
